<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip?lang_cible=oc_ni_la
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'access_interface_graphique' => 'Tornar a l’interfàcia grafica completa',
	'access_mode_texte' => 'Afichar l’interfàcia textuala simplificada',
	'admin_debug' => 'desbugatge',
	'admin_modifier_article' => 'Modificar aquel article',
	'admin_modifier_auteur' => 'Modificar aquel autor',
	'admin_modifier_breve' => 'Modificar aquela brèva',
	'admin_modifier_mot' => 'Modificar aqueu mot clau',
	'admin_modifier_rubrique' => 'Modificar aquela rubrica',
	'admin_recalculer' => 'Tornar calcular la pàgina',
	'alerte_maj_impossible' => '<b>Alèrta!</b> Es impossible d’actualizar la basa SQL vèrs la version @version@; benlèu i a un problèma relatiu au drech de modificar la basa de donadas. Vorgatz contactar lo vòstre aubergador.',
	'analyse_xml' => 'Analisi XML',
	'articles_recents' => 'Lu articles mai recents',
	'avis_archive_incorrect' => 'lo fichier archiu non es un fichier SPIP',
	'avis_archive_invalide' => 'lo fichier archiu non es valid',
	'avis_attention' => 'ATENCION!',
	'avis_champ_incorrect_type_objet' => 'Nom de camp incorrècte @name@ per objècte de tipe @type@',
	'avis_colonne_inexistante' => 'La colomna @col@ non existisse',
	'avis_erreur' => 'Error: veètz çai sota',
	'avis_erreur_connexion' => 'Error de connexion',
	'avis_erreur_cookie' => 'problèma de cookie',
	'avis_erreur_fonction_contexte' => 'Error de programacion. Non cau apelar aquela foncion dins aqueu contèxt.',
	'avis_erreur_mysql' => 'Error SQL ',
	'avis_erreur_sauvegarde' => 'Error dins la sauvagarda (@type@ @id_objet@)! ',

	// B
	'barre_a_accent_grave' => 'Inserir una A accent grèu majuscula',
	'barre_aide' => 'Utilizar li acorchas tipografiqui per enriquir la vòstra compaginacion',
	'barre_e_accent_aigu' => 'Inserir una E accent agut majuscula',
	'barre_eo' => 'Inserir una E dins l’O',
	'barre_eo_maj' => 'Inserir una E dins l’O majuscula',
	'barre_euro' => 'Inserir lo simbèu de l’èuro: €',
	'barre_gras' => 'Metre en {{gras}}',
	'barre_guillemets' => 'Enrodar emb de « verguetas »',
	'barre_guillemets_simples' => 'Enrodar emb de verguetas',
	'barre_intertitre' => 'Transformar en {{{intertítol}}}',
	'barre_italic' => 'Metre en {italics}',
	'barre_lien' => 'Transformar en [ligam ipertèxt->http://...]',
	'barre_lien_input' => 'Vorgatz indicar l’adreiça dau vòstre ligam (podètz indicar una adreiça web sota la forma http://www.lomieusit.com ò simplament indicar lo número d’un article d’aqueu sit).',
	'barre_note' => 'Transformar en [[Nòta de pè]]',
	'barre_quote' => '<quote>Citar un messatge</quote>',
	'bouton_changer' => 'Cambiar',
	'bouton_chercher' => 'Cercar',
	'bouton_choisir' => 'Chausir',
	'bouton_enregistrer' => 'Registrar',
	'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la messatjaria intèrna',
	'bouton_radio_envoi_annonces' => 'Mandar lu anoncis editoriaus',
	'bouton_radio_non_envoi_annonces' => 'Non mandar d’anoncis',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Non mandar la tiera dei novetats',
	'bouton_recharger_page' => 'tornar cargar aquela pàgina',
	'bouton_telecharger' => 'Telecargar',
	'bouton_upload' => 'Telecargar', # MODIF
	'bouton_valider' => 'Validar',

	// C
	'cal_apresmidi' => 'aprèsmiegjorn',
	'cal_jour_entier' => 'jorn entier',
	'cal_matin' => 'matin',
	'cal_par_jour' => 'calendier per jorn',
	'cal_par_mois' => 'calendier per mes',
	'cal_par_semaine' => 'calendier per setmana',
	'confirm_changer_statut' => 'Atencion, avètz demandat de cambiar l’estatut d’aquel element. Desiratz de contunhar? ',

	// D
	'date_aujourdhui' => 'ancuei',
	'date_avant_jc' => 'avans lo Crist',
	'date_dans' => 'd’aquí @delai@',
	'date_de_mois_1' => '@j@ de genoier',
	'date_de_mois_10' => '@j@ d’octòbre',
	'date_de_mois_11' => '@j@ de novembre',
	'date_de_mois_12' => '@j@ de decembre',
	'date_de_mois_2' => '@j@ de febrier',
	'date_de_mois_3' => '@j@ de març',
	'date_de_mois_4' => '@j@ d’abriu',
	'date_de_mois_5' => '@j@ de mai',
	'date_de_mois_6' => '@j@ de junh',
	'date_de_mois_7' => '@j@ de julhet',
	'date_de_mois_8' => '@j@ d’aost',
	'date_de_mois_9' => '@j@ de setembre',
	'date_demain' => 'deman',
	'date_fmt_heures_minutes' => '@h@h@m@min',
	'date_fmt_jour_heure' => '@jour@ a @heure@',
	'date_fmt_jour_mois' => '@jourmois@',
	'date_fmt_jour_mois_annee' => '@jourmois@ dau @annee@',
	'date_fmt_mois_annee' => '@nommois@ dau @annee@',
	'date_fmt_nomjour_date' => 'lo @nomjour@ @date@',
	'date_heures' => 'oras',
	'date_hier' => 'ièr',
	'date_il_y_a' => 'fa @delai@',
	'date_jnum1' => '1r',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => '2',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'diménegue',
	'date_jour_2' => 'diluns',
	'date_jour_3' => 'dimars',
	'date_jour_4' => 'dimècres',
	'date_jour_5' => 'dijòus',
	'date_jour_6' => 'divendres',
	'date_jour_7' => 'dissabta',
	'date_jours' => 'jorns',
	'date_minutes' => 'minutas',
	'date_mois' => 'mes',
	'date_mois_1' => 'genoier',
	'date_mois_10' => 'octòbre',
	'date_mois_11' => 'novembre',
	'date_mois_12' => 'decembre',
	'date_mois_2' => 'febrier',
	'date_mois_3' => 'març',
	'date_mois_4' => 'abriu',
	'date_mois_5' => 'mai',
	'date_mois_6' => 'junh',
	'date_mois_7' => 'julhet',
	'date_mois_8' => 'aost',
	'date_mois_9' => 'setembre',
	'date_saison_1' => 'ivèrn',
	'date_saison_2' => 'prima',
	'date_saison_3' => 'estiu',
	'date_saison_4' => 'auton',
	'date_semaines' => 'setmana(s)',
	'dirs_commencer' => 'per començar verament l’installacion',
	'dirs_preliminaire' => 'Preliminar: <b>Reglar lu drechs d’accès</b>',
	'dirs_probleme_droits' => 'Problèma de drechs d’accès',
	'dirs_repertoires_absents' => '<b>Non s’es trobat lu repertòris seguents: <ul>@bad_dirs@.</ul> </b>
  <p>Si pòu que venga d’un problèma de majusculas ò minusculas mau mesas.
  Verificatz que li minusculas e majusculas d’aquelu repertòris correspòndan ben emb cen afichat
  çai subre; se non es lo cas, tornatz nommar lu repertòris embau vòstre logiciau FTP en corregissent l’error.
  <p>Un còup qu’auretz fach aquò, porretz ',
	'dirs_repertoires_suivants' => '<b>Lu repertòris seguents non son accessibles en escritura: <ul>@bad_dirs@.</ul> </b>
  <p>Per adobar aquò, utilizatz lo vòstre client FTP per fin de reglar lu drechs d’accès de cadun
  d’aquelu repertòris. La guida d’installacion explica en detalh coma cau procedir.
  <p>Tre qu’auretz facha aquela manipulacion, porretz </p>',

	// E
	'envoi_via_le_site' => 'Mandadís embau biais dau sit web',

	// F
	'fichier_introuvable' => 'Non s’es pogut trobar lo fichier @fichier@.', # MODIF
	'form_deja_inscrit' => 'Siatz ja inscrich(a).',
	'form_email_non_valide' => 'La vòstra adreiça e-mail non es valida.',
	'form_forum_access_refuse' => 'Podètz pus accedir a aqueu sit.',
	'form_forum_bonjour' => 'Bònjorn @nom@,',
	'form_forum_email_deja_enregistre' => 'Aquela adreiça e-mail ja es registrada, doncas podètz utilizar lo vòstre mot de santa Clara costumier.',
	'form_forum_identifiant_mail' => 'V’avèm mandat lo vòstre identificant novèu per e-mail.',
	'form_forum_identifiants' => 'Identificants personaus',
	'form_forum_indiquer_nom_email' => 'Indicatz aquí lo vòstre nom e la vòstra adreiça e-mail. Lo vòstre identificant personau arribarà lèu-lèu, per e-mail.',
	'form_forum_login' => 'login:',
	'form_forum_message_auto' => '(aquò’s un messatge automatic)',
	'form_forum_pass' => 'mot de santa Clara:',
	'form_forum_probleme_mail' => 'Problèma d’e-mail: non si pòu mandar l’identificant.',
	'form_forum_voici1' => 'Vètz lu vòstres identificants per poder participar ai forums
dau sit "@nom_site_spip@" (@adresse_site@):',
	'form_forum_voici2' => 'Vètz lu vòstres identificants per prepauar d’articles 
 sus lo sit "@nom_site_spip@" (@adresse_login@):',
	'form_indiquer_email' => 'Vorgatz indicar la vòstra adreiça e-mail.',
	'form_indiquer_nom' => 'Vorgatz indicar lo vòstre nom.',
	'form_indiquer_nom_site' => 'Vorgatz indicar lo nom dau vòstre sit.',
	'form_pet_deja_enregistre' => 'Ja aqueu sit es registrat',
	'form_pet_signature_pasprise' => 'La vòstra signatura non es pilhada en còmpte.',
	'form_prop_confirmer_envoi' => 'Confirmar lo mandadís',
	'form_prop_description' => 'Descripcion/comentari',
	'form_prop_enregistre' => 'La vòstra proposicion es ben registrada, apareisserà en linha tre que lu responsables dau sit l’auràn validada.',
	'form_prop_envoyer' => 'Mandar un messatge',
	'form_prop_indiquer_email' => 'Vorgatz indicar una adreiça e-mail valida',
	'form_prop_indiquer_nom_site' => 'Vorgatz indicar lo nom dau sit.',
	'form_prop_indiquer_sujet' => 'Vorgatz indicar un subjècte',
	'form_prop_message_envoye' => 'Messatge mandat',
	'form_prop_non_enregistre' => 'La vòstra propòsta non es estada registrada.',
	'form_prop_sujet' => 'Subjècte',
	'form_prop_url_site' => 'Adreiça (URL) dau sit', # MODIF
	'forum_non_inscrit' => 'Sia non siatz inscrich(a), sia avètz fach un error d’adreiça ò de mot de santa Clara. ',
	'forum_par_auteur' => 'per @auteur@',
	'forum_titre_erreur' => 'Error...',

	// I
	'ical_texte_rss_articles' => 'Lo fichier "backend" dei articles d’aquest sit si tròba a l’adreiça: ',
	'ical_texte_rss_articles2' => 'Parier podètz obtenir de fichiers "backend" per lu articles de cada rubrica dau sit:',
	'ical_texte_rss_breves' => 'Existisson mai d’un fichier contenent li brèvas dau sit. En precisant un número de rubrica,  obtendretz basta li brèvas de la rubrica aquela.',
	'icone_a_suivre' => 'De sègre',
	'icone_admin_site' => 'Administracion dau sit',
	'icone_agenda' => 'Agenda',
	'icone_aide_ligne' => 'Ajuda',
	'icone_articles' => 'Articles',
	'icone_auteurs' => 'Autors',
	'icone_brouteur' => 'Navigacion rapida',
	'icone_configuration_site' => 'Configuracion',
	'icone_configurer_site' => 'Configurar lo vòstre sit',
	'icone_creer_nouvel_auteur' => 'Crear un autor nòu ',
	'icone_creer_rubrique' => 'Crear una rubrica',
	'icone_creer_sous_rubrique' => 'Crear una sosrubrica',
	'icone_deconnecter' => 'Si desconnectar',
	'icone_discussions' => 'Discussions',
	'icone_doc_rubrique' => 'Documents dei rubricas',
	'icone_ecrire_article' => 'Escriure un article nòu',
	'icone_edition_site' => 'Edicion',
	'icone_gestion_langues' => 'Gestion dei lengas',
	'icone_informations_personnelles' => 'Informacions personali',
	'icone_interface_complet' => 'Interfàcia completa',
	'icone_interface_simple' => 'Interfàcia simplificada',
	'icone_maintenance_site' => 'Mantenença dau sit',
	'icone_messagerie_personnelle' => 'Messatjaria personala',
	'icone_repartition_debut' => 'Afichar la reparticion despí la començança',
	'icone_rubriques' => 'Rubricas',
	'icone_sauver_site' => 'Sauvagarda dau sit',
	'icone_site_entier' => 'Tot lo sit ',
	'icone_sites_references' => 'Sits referenciats',
	'icone_statistiques' => 'Estadisticas dau sit',
	'icone_suivi_activite' => 'Sègre la vida dau sit',
	'icone_suivi_actualite' => 'Evolucion dau sit',
	'icone_suivi_pettions' => 'Sègre/gerir li peticions',
	'icone_suivi_revisions' => 'Modificacions dei articles',
	'icone_supprimer_document' => 'Suprimir aqueu document',
	'icone_supprimer_image' => 'Suprimir aquel imatge',
	'icone_tous_articles' => 'Toi lu vòstres articles ',
	'icone_tous_auteur' => 'Toi lu autors ',
	'icone_visiter_site' => 'Vesitar', # MODIF
	'icone_voir_en_ligne' => 'Veire en linha',
	'img_indisponible' => 'imatge indisponible',
	'info_a_suivre' => 'DE SÈGRE&gt;&gt;',
	'info_acces_interdit' => 'Accès proïbit',
	'info_acces_refuse' => 'Accès refusat',
	'info_action' => 'Accion: @action@',
	'info_administrer_rubriques' => 'Podètz administrar aquela rubrica e li sieus sosrubricas',
	'info_adresse_non_indiquee' => 'Non avètz indicat l’adreiça de testar!',
	'info_aide' => 'AJUDA:',
	'info_ajouter_mot' => 'Apondre aqueu mot',
	'info_annonce' => 'ANONCI',
	'info_annonces_generales' => 'Anoncis generaus:',
	'info_article_propose' => 'Article prepauat',
	'info_article_publie' => 'Article publicat',
	'info_article_redaction' => 'Article en cors de redaccion',
	'info_article_refuse' => 'Article refusat',
	'info_article_supprime' => 'Article suprimit',
	'info_articles' => 'Articles',
	'info_articles_a_valider' => 'Lu articles de validar',
	'info_articles_proposes' => 'Articles prepauats',
	'info_auteurs_nombre' => 'autor(s)',
	'info_authentification_ftp' => 'autentificacion (per FTP).',
	'info_breves_2' => 'brèvas',
	'info_connexion_refusee' => 'Connexion refusada',
	'info_contact_developpeur' => 'Vorgatz contactar un desvolopaire.',
	'info_contenance' => 'Aqueu sit conten:',
	'info_contribution' => 'Contribucions de forum', # MODIF
	'info_copyright' => '@spip@ es un logiciau liure distribuit @lien_gpl@.',
	'info_copyright_doc' => 'Per mai d’informacions, veire lo sit <a href="@spipnet@">http://www.spip.net/oc</a>.', # MODIF
	'info_copyright_gpl' => 'sota licéncia GPL',
	'info_cours_edition' => 'Li vòstres articles en cors de redaccion', # MODIF
	'info_creer_repertoire' => 'Vorgatz crear un fichier ò un repertòri nommat',
	'info_creer_repertoire_2' => 'dintre lo sosrepertòri   <b>@repertoire@</b>, pi:',
	'info_creer_vignette' => 'creacion automatica de la vinheta',
	'info_deplier' => 'Desplegar',
	'info_descriptif_nombre' => 'descriptiu(s):',
	'info_description' => 'Descripcion:',
	'info_description_2' => 'Descripcion:',
	'info_dimension' => 'Dimensions:',
	'info_ecire_message_prive' => 'Escriure un messatge privat',
	'info_email_invalide' => 'Adreiça e-mail invalida',
	'info_en_cours_validation' => 'Lu vòstres articles en cors de redaccion',
	'info_en_ligne' => 'Aüra en linha:',
	'info_envoyer_message_prive' => 'Mandar un messatge privat a aquel autor',
	'info_erreur_requete' => 'Error dins la requista',
	'info_erreur_squelette2' => 'Minga d’esqueleta <b>@fichier@</b> es disponibla...',
	'info_erreur_systeme' => 'Error sistèma (errno @errsys@)',
	'info_erreur_systeme2' => 'Lo disc dur es benlèu plen, ò la basa de donadas degalhada.<br />
<span style="color:red;">Assaiatz de <a href=\'@script@\'>reparar la basa</a>, ò contactatz lo vòstre aubergador.</span>',
	'info_fini' => 'Es acabat!',
	'info_format_image' => 'Formats d’imatges que si pòdon utilizar per crear de vinhetas: @gd_formats@.',
	'info_format_non_defini' => 'format non definit',
	'info_grand_ecran' => 'Ecran grand',
	'info_image_aide' => 'AJUDA',
	'info_image_process_titre' => 'Metòde de fabricacion dei vinhetas',
	'info_impossible_lire_page' => '<b>Error!</b> Impossible de legir la pàgina <tt><html>@test_proxy@</html></tt> a travèrs dau proxy <tt>',
	'info_installation_systeme_publication' => 'Installacion dau sistèma de publicacion...',
	'info_installer_documents' => 'Podètz installar automaticament toi lu documents contenguts dins lo repertòri @upload@.',
	'info_installer_ftp' => 'Coma administrator, podètz installar (per FTP) de fichiers dins lo dorsier @upload@, pi lu seleccionar directament aicí.',
	'info_installer_images' => 'Podètz installar d’imatges ai formats JPEG, GIF e PNG.',
	'info_installer_images_dossier' => 'Installar d’imatges dins lo dorsier @upload@ per lu poder seleccionar aicí.',
	'info_interface_complete' => 'Interfàcia completa',
	'info_interface_simple' => 'Interfàcia simplificada',
	'info_joindre_document_article' => 'Podètz jónher a aquel article de documents de la mena de',
	'info_joindre_document_rubrique' => 'Podètz apondre a aquela rubrica de documents de la mena de',
	'info_joindre_documents_article' => 'Podètz jónher a aquel article de documents de la mena de:',
	'info_l_article' => 'l’article',
	'info_la_breve' => 'la brèva',
	'info_la_rubrique' => 'la rubrica',
	'info_langue_principale' => 'Lenga majorala dau sit',
	'info_largeur_vignette' => '@largeur_vignette@ x @hauteur_vignette@ pixèls',
	'info_les_auteurs_1' => 'per @les_auteurs@ ',
	'info_logo_format_interdit' => 'Lu lògos de formats @formats@ son solets autorizats.',
	'info_logo_max_poids' => 'Lu lògos an de far mens de @maxi@ (aquest fichier fa @actuel@).',
	'info_mail_fournisseur' => 'vos@fornidor.com',
	'info_message_2' => 'MESSATGE',
	'info_message_supprime' => 'MESSATGE SUPRIMIT',
	'info_mise_en_ligne' => 'Data de mesa en linha:',
	'info_modification_parametres_securite' => 'modificacions dei paramètres de seguretat',
	'info_mois_courant' => 'Dins lo corrent dau mes:',
	'info_mot_cle_ajoute' => 'S’es apondut lo mot clau seguent a',
	'info_multi_herit' => 'Lenga predefinida',
	'info_multi_langues_soulignees' => 'Li <u>lengas solinhadi</u> benefícian d’una revirada de toi lu tèxts de l’interfàcia. Se seleccionatz aqueli lengas, tot plen d’elements dau sit public (datas, formularis) si reviraràn automaticament. Per li lengas non solinhadi, aquelu elements apareisseràn dins la lenga principala dau sit.', # MODIF
	'info_multilinguisme' => 'Multilingüisme',
	'info_nom_non_utilisateurs_connectes' => 'Lo vòstre nom non apareisse dins la tiera dei utilizaires connectats.',
	'info_nom_utilisateurs_connectes' => 'Lo vòstre nom apareisse dins la tiera dei utilizaires connectats.',
	'info_nombre_en_ligne' => 'Aüra en linha:',
	'info_non_resultat' => 'Minga de resultat per "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'Non utilizatz la messatjaria intèrna d’aqueu sit.',
	'info_nouveau_message' => 'AVÈTZ UN MESSATGE NÒU',
	'info_nouveaux_messages' => 'AVÈTZ @total_messages@ MESSATGES NÒUS',
	'info_numero_abbreviation' => 'N° ',
	'info_pense_bete' => 'MEMENTO',
	'info_petit_ecran' => 'Ecran pichin ',
	'info_pixels' => 'pixèls',
	'info_plusieurs_mots_trouves' => 'plusors mots clau trobats per "@cherche_mot@":',
	'info_portfolio_automatique' => 'Pòrtfòlio automatic:',
	'info_premier_resultat' => '[@debut_limit@ primiers resultats de @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ primiers resultats de @total@]',
	'info_propose_1' => '[@nom_site_spip@] Prepaua: @titre@',
	'info_propose_2' => 'Article prepauat
---------------',
	'info_propose_3' => 'L’article "@titre@" es prepauat a la publicacion.',
	'info_propose_4' => 'Vos convidam a lo venir consultar e a donar lo vòstre vejaire',
	'info_propose_5' => 'dins lo forum que li es estacat. Es disponible a l’adreiça:',
	'info_publie_01' => 'L’article "@titre@" es estat validat per @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] PUBLICA: @titre@',
	'info_publie_2' => 'Article publicat
--------------',
	'info_rechercher' => 'Cercar',
	'info_rechercher_02' => 'Cercar:',
	'info_remplacer_vignette' => 'Remplaçar la vinheta predefinida per un lògo personalizat:',
	'info_sans_titre_2' => 'sensa títol',
	'info_selectionner_fichier' => 'Podètz seleccionar un fichier dau dorsier @upload@',
	'info_selectionner_fichier_2' => 'Seleccionar un fichier:',
	'info_supprimer_vignette' => 'suprimir la vinheta',
	'info_symbole_bleu' => 'Lo simbèu <b>blau</b> marca un <b>memento</b>: valent a dire un messatge per lo vòstre usatge personau.',
	'info_symbole_jaune' => 'Lo simbèu <b>jaune</b> marca un <b>anonci per toi lu redactors </b>: lu administrators lo pòdon modificar, cada redactor lo pòu veire.',
	'info_symbole_vert' => 'Lo simbèu <b>verd</b> marca lu <b>messatges escambiats emb d’autres utilizaires</b> dau sit.',
	'info_telecharger_nouveau_logo' => 'Telecargar un lògo nòu:',
	'info_telecharger_ordinateur' => 'Telecargar a partir dau vòstre ordenador:',
	'info_tous_resultats_enregistres' => '[toi lu resultats son registrats]',
	'info_tout_afficher' => 'Afichar tot',
	'info_travaux_texte' => 'Aqueu sit non es encara configurat. Tornatz mai tard...',
	'info_travaux_titre' => 'Sit en òbras',
	'info_trop_resultat' => 'Tròup de resultats per "@cherche_mot@"; vorgatz afinar la cèrca.',
	'info_utilisation_messagerie_interne' => 'Utilizatz la messatjaria intèrna d’aqueu sit.',
	'info_valider_lien' => 'validar aqueu ligam',
	'info_verifier_image' => ', vorgatz verificar que lu imatges si sigan ben transferits.',
	'info_vignette_defaut' => 'Vinheta predefinida',
	'info_vignette_personnalisee' => 'Vinheta personalizada',
	'info_visite' => 'vesita:',
	'info_vos_rendez_vous' => 'Lu vòstres rendètz-vos venents',
	'infos_vos_pense_bete' => 'Lu vòstres mementos', # MODIF

	// L
	'lien_afficher_icones_seuls' => 'Afichar basta li icònas ',
	'lien_afficher_texte_icones' => 'Afichar basta li icònas e lo tèxt',
	'lien_afficher_texte_seul' => 'Afichar basta lo tèxt ',
	'lien_liberer' => 'liberar',
	'lien_liberer_tous' => 'liberar aquelu articles', # MODIF
	'lien_nouvea_pense_bete' => 'MEMENTO NÒU',
	'lien_nouveau_message' => 'MESSATGE NÒU',
	'lien_nouvelle_annonce' => 'ANONCI NOVÈU',
	'lien_petitions' => 'PETICION',
	'lien_popularite' => 'popularitat: @popularite@%',
	'lien_racine_site' => 'RAIÇ DAU SIT',
	'lien_reessayer' => 'tornar assaiar',
	'lien_repondre_message' => 'Respòndre a aqueu messatge',
	'lien_supprimer' => 'suprimir',
	'lien_tout_afficher' => 'Afichar tot',
	'lien_visite_site' => 'vesitar aqueu sit',
	'lien_visites' => '@visites@ vesitas',
	'lien_voir_auteur' => 'Veire aquel autor',
	'login_acces_prive' => 'accès a l’espaci privat',
	'login_autre_identifiant' => 'si connectar emb un autre identificant',
	'login_cookie_accepte' => 'Vorgatz configurar lo vòstre navigador per que lu accèpte (aumens per aqueu sit).',
	'login_cookie_oblige' => 'Per v’identificar d’un biais segur sus aquest sit, vos cau acceptar lu cookies.',
	'login_deconnexion_ok' => 'Siatz desconnectat/ada.',
	'login_erreur_pass' => 'Error de mot de santa Clara.',
	'login_espace_prive' => 'espaci privat',
	'login_identifiant_inconnu' => 'L’identificant «@login@» es inconegut.',
	'login_login' => 'Login:',
	'login_login2' => 'Login (identificant de connexion au sit):', # MODIF
	'login_login_pass_incorrect' => '(Login ò mot de santa Clara incorrècte.)',
	'login_motpasseoublie' => 'mot de santa Clara oblidat?',
	'login_non_securise' => 'Atencion, aqueu formulari non es securizat.
    Se non volètz que lo vòstre mot de santa Clara sia
   interceptat sus la ret, vorgatz activar Javascript 
   dins lo vòstre navigador e',
	'login_nouvelle_tentative' => 'novèl assai',
	'login_par_ici' => 'Siatz registrat/ada... per aquí...',
	'login_pass2' => 'Mot de santa Clara:',
	'login_preferez_refuser' => '<b>Se v’agrada mai de refusar lu cookies</b>, un autre metòde de connexion (mens securizat) es a la vòstra disposicion:',
	'login_recharger' => 'tornar cargar aquela pàgina',
	'login_rester_identifie' => 'Restar identificat/ada quaucu jorns', # MODIF
	'login_retour_public' => 'Tornar au sit public',
	'login_retour_site' => 'Tornar au sit public',
	'login_retoursitepublic' => 'tornar au sit public',
	'login_sinscrire' => 's’inscriure',
	'login_test_navigateur' => 'Assai navigador/tornar connectar',
	'login_verifiez_navigateur' => '(totun verificatz que lo vòstre navigador non auga servat lo vòstre mot de santa Clara en memòria...)',

	// M
	'module_fichiers_langues' => 'Fichiers de lenga',

	// N
	'navigateur_pas_redirige' => 'Se lo vòstre navigador non es redirigit, clicatz aicí per contunhar.',

	// O
	'onglet_affacer_base' => 'Esfaçar la basa',
	'onglet_auteur' => 'L’autor',
	'onglet_contenu_site' => 'Contengut dau sit',
	'onglet_evolution_visite_mod' => 'Evolucion',
	'onglet_fonctions_avances' => 'Foncions avançadi',
	'onglet_informations_personnelles' => 'Informacions personali',
	'onglet_interactivite' => 'Interactivitat',
	'onglet_messagerie' => 'Messatjaria',
	'onglet_repartition_rubrique' => 'Reparticion per rubricas',
	'onglet_save_restaur_base' => 'Sauvagardar/restaurar la basa',
	'onglet_vider_cache' => 'Vuar l’escondedor',

	// P
	'pass_choix_pass' => 'Vorgatz chausir lo vòstre mot de santa Clara novèu:',
	'pass_erreur' => 'Error',
	'pass_erreur_acces_refuse' => '<b>Error :</b> podètz pus accedir a aqueu sit.',
	'pass_erreur_code_inconnu' => '<b>Error :</b> aqueu còde correspònde a minga de vesitaire que pòsca accedir a aqueu sit.',
	'pass_erreur_non_enregistre' => '<b>Error:</b> l’adreiça <tt>@email_oubli@</tt> non es registrada sus aqueu sit.',
	'pass_erreur_non_valide' => '<b>Error:</b> aquel e-mail <tt>@email_oubli@</tt> non es valid!',
	'pass_erreur_probleme_technique' => '<b>Error:</b> per amòr d’un problèma tecnic, l’e-mail non si pòu mandar. ',
	'pass_espace_prive_bla' => 'L’espaci privat d’aquest sit es dubèrt ai
  vesitaires que si son inscrichs. Un còup registrat/ada,
  porretz consultar lu articles en cors de redaccion,
  prepausar d’articles novèus e participar a totei lei forums.',
	'pass_forum_bla' => 'Avètz demandat d’intervenir dins un forum
  reservat ai vesitaires registrats.',
	'pass_indiquez_cidessous' => 'Marcatz çai sota l’adreiça e-mail dont
 vos registreriatz lo còup passat. 
   Recebretz un e-mail que vos donarà lo biais de 
    tornar trobar lo vòstre accès.',
	'pass_mail_passcookie' => '(aquò es un messatge automatic)
Per tornar trobar o vòstre accès au sit
@nom_site_spip@ (@adresse_site@)

Vorgatz anar a l’adreiça seguenta:

    @sendcookie@

Alora porretz intrar un mot de santa Clara novèu
e vos tornar connectar au sit.

',
	'pass_mot_oublie' => 'Mot de santa Clara demembrat',
	'pass_nouveau_enregistre' => 'Lo vòstre mot de santa Clara novèu es estat registrat.',
	'pass_nouveau_pass' => 'Mot de santa Clara novèu',
	'pass_ok' => 'D’acòrdi',
	'pass_oubli_mot' => 'Mot de santa Clara demembrat',
	'pass_quitter_fenetre' => 'Quitar aquesta fenèstra ',
	'pass_rappel_login' => 'Remembrança: lo vòstre identificant (login) es «@login@».',
	'pass_recevoir_mail' => 'Recebretz un e-mail que v’explicarà coma tornar trobar lo vòstre accès au sit.', # MODIF
	'pass_retour_public' => 'Tornar au sit public',
	'pass_rien_a_faire_ici' => 'Ren a faire aicí.',
	'pass_vousinscrire' => 'S’inscriure sus aquest sit',
	'precedent' => 'precedent',
	'previsualisation' => 'Previsualizacion',
	'previsualiser' => 'Previsualizar',

	// S
	'stats_visites_et_popularite' => '@visites@ vesitas; popularitat: @popularite@',
	'suivant' => 'seguent',

	// T
	'taille_ko' => '@taille@ Ko',
	'taille_mo' => '@taille@ Mo',
	'taille_octets' => '@taille@ octets',
	'texte_actualite_site_1' => 'Quand vos seretz familharizat/ada emb l’interfàcia, porretz clicar sus «',
	'texte_actualite_site_2' => 'Interfàcia completa',
	'texte_actualite_site_3' => '" per durbir mai de possibilitats.',
	'texte_creation_automatique_vignette' => 'La creacion automatica de vinhetas de previsualizacion es activada sus aqueu sit. S’installatz a partir d’aqueu formulari d’imatges au(ai) format(s) @gd_formats@, s’acompanharàn d’una vinheta d’una talha maximala de @taille_preview@ pixèls.',
	'texte_documents_associes' => 'Lu documents seguents s’assòcian a l’article,
 mas non s’inserisson
 directament. Segon la compaginacion dau sit public,
 porràn aparéisser sota forma de documents jonchs.',
	'texte_erreur_mise_niveau_base' => 'Error de basa de donadas pendent la mesa a nivèu. L’imatge <b>@fichier@</b> non es passat (article @id_article@).
  Notatz ben aquela referéncia, tornatz assaiar la mesa a
 nivèu, e verificatz pi que lu imatges aparegan
 encara dins lu articles.',
	'texte_inc_auth_1' => 'Siatz identificat/ada coma
   <b>@auth_login@</b>, mas aqueu login non existisse ò existisse pus dins la basa.
  Assaiatz de vos', # MODIF
	'texte_inc_auth_2' => 'tornar connectar',
	'texte_inc_auth_3' => ', après qu’auretz quitat eventualament, pi
  tornat lançar lo vòstre navigador.',
	'texte_inc_config' => 'Li modificacions fachi dins aquesti pàginas influéncian bravament lo
 foncionament dau vòstre sit. V’aconselham de non i intervenir tant que siatz pas
 acostumat/ada au foncionament dau sistèma SPIP. <br /><br /><b>
 En generau, si conselha tot plen
 de laissar la carga d’aquesti pàginas au webmèstre principau dau vòstre sit.</b>',
	'texte_inc_meta_1' => 'Lo sistèma a rescontrat un error dins l’escritura dau fichier <code>@fichier@</code>.Vougatz, coma administrator/tritz dau sit,',
	'texte_inc_meta_2' => 'verificar lu drechs d’escritura',
	'texte_inc_meta_3' => 'dins lo repertòri <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'en cors de redaccion',
	'texte_statut_poubelle' => 'au bordilhier',
	'texte_statut_propose_evaluation' => 'prepauat per avaloracion',
	'texte_statut_publie' => 'publicat en linha',
	'texte_statut_refuse' => 'refusat',
	'titre_ajouter_mot_cle' => 'APONDRE UN MOT CLAU:',
	'titre_cadre_raccourcis' => 'ACORCHAS:',
	'titre_changer_couleur_interface' => 'Cambiar lo color de l’interfàcia',
	'titre_image_admin_article' => 'Podètz administrar aquest article',
	'titre_image_administrateur' => 'Administrator',
	'titre_image_aide' => 'D’ajuda sobre aquel element',
	'titre_image_auteur_supprime' => 'Autor suprimit',
	'titre_image_redacteur' => 'Redactor sensa accès',
	'titre_image_redacteur_02' => 'Redactor',
	'titre_image_visiteur' => 'Vesitaire',
	'titre_joindre_document' => 'JÓNHER UN DOCUMENT',
	'titre_mots_cles' => 'MOTS CLAU',
	'titre_probleme_technique' => 'Atencion: un problèma tecnic (servidor SQL) empedisse d’accedir a aquela part dau sit. Mercé de la vòstra indulgéncia.',
	'titre_publier_document' => 'PUBLICAR UN DOCUMENT DINS AQUELA RUBRICA',
	'titre_statistiques' => 'Estadisticas dau sit',
	'titre_titre_document' => 'Títol dau document:',
	'trad_reference' => '(article de referéncia)', # MODIF

	// Z
	'zbug_balise_b_aval' => ' : balisa B en avau',
	'zbug_boucle' => 'bloca',
	'zbug_boucle_recursive_undef' => 'bloca recursiva non definida', # MODIF
	'zbug_champ_hors_boucle' => 'Camp @champ@ fòra bloca',
	'zbug_champ_hors_motif' => 'Camp @champ@ en defòra d’una bloca de motiu @motif@', # MODIF
	'zbug_code' => 'còde',
	'zbug_critere_inconnu' => 'critèri inconegut @critere@', # MODIF
	'zbug_distant_interdit' => 'extèrne enebit', # MODIF
	'zbug_erreur_boucle_double' => 'BLOCA@id@: definicion dobla', # MODIF
	'zbug_erreur_boucle_fermant' => 'BLOCA@id@: lo tag barrador manca', # MODIF
	'zbug_erreur_boucle_syntaxe' => 'Sintaxi bloca incorrècta', # MODIF
	'zbug_erreur_execution_page' => 'error d’execucion de la pàgina', # MODIF
	'zbug_erreur_filtre' => 'Error: filtre <b>« @filtre@ »</b> non definit', # MODIF
	'zbug_erreur_meme_parent' => '{meme_parent} s’aplica basta ai blocas (FORUMS) o (RUBRIQUES)', # MODIF
	'zbug_erreur_squelette' => 'Error(s) dins l’esqueleta',
	'zbug_info_erreur_squelette' => 'Error sobre lo sit',
	'zbug_inversion_ordre_inexistant' => 'inversion d’un òrdre inexistent', # MODIF
	'zbug_parametres_inclus_incorrects' => 'Paramètres d’inclusion incorrèctes', # MODIF
	'zbug_resultat' => 'resultat',
	'zbug_serveur_indefini' => 'servidor SQL indefinit', # MODIF
	'zbug_table_inconnue' => 'Taula SQL «@table@» inconeguda'
);
